
from setuptools import setup


setup(
    author="@LoisaidaSam",
    author_email="sam.sandberg@gmail.com",
    description="A Python wrapper for Slack's API",
    install_requires=["requests"],
    keywords="slack api wrapper",
    license="MIT",
    name="pyslack-real",
    packages=["pyslack"],
    test_suite="tests",
    url="https://github.com/loisaidasam/pyslack",
    version="0.5.3",
)
